@@ -69,6 +69,8 @@ class Desktop(MethodsInterface):
         """
         userPwd = getKey(userName)
         error = ""
+        # запуск демона eCryptfs
+        os.system('/usr/bin/ecryptfsd')
         # проверить наличие пароля в ключах ядра
         if not userPwd or userPwd == "XXXXXXXX":
             raise DesktopError(_("User password not found"))
